@@ -1,4 +1,4 @@
 library("testthat")
 library("arulesCBA")
 
-test_check("arulesCBA")
\ No newline at end of file
+testthat::test_check("arulesCBA")
